@@ -1,6 +1,6 @@
 /*
  * gaim - Gadu-Gadu Protocol Plugin
- * $Id: gg.c,v 1.17 2001/12/22 00:41:30 warmenhoven Exp $
+ * $Id: gg.c,v 1.18 2002/03/12 17:21:43 seanegan Exp $
  *
  * Copyright (C) 2001 Arkadiusz Mikiewicz <misiek@pld.ORG.PL>
  * 
@@ -585,7 +585,7 @@ static void agg_close(struct gaim_connection *gc)
 	gd->own_status = GG_STATUS_NOT_AVAIL;
 }
 
-static int agg_send_im(struct gaim_connection *gc, char *who, char *msg, int flags)
+static int agg_send_im(struct gaim_connection *gc, char *who, char *msg, int len, int flags)
 {
 	struct agg_data *gd = (struct agg_data *)gc->proto_data;
 	gchar *imsg;
