@@ -79,6 +79,11 @@
 #define FILE_GET_UID  "09461348-4C7F-11D1-8222-444553540000"
 #define GAMES_UID     "0946134a-4C7F-11D1-8222-444553540000"
 
+#define UC_AOL		0x02
+#define UC_ADMIN	0x04
+#define UC_UNCONFIRMED	0x08
+#define UC_NORMAL	0x10
+
 struct ft_request {
 	struct gaim_connection *gc;
         char *user;
@@ -125,7 +130,6 @@ struct signon {
 
 static void toc_login_callback(gpointer, gint, GaimInputCondition);
 static void toc_callback(gpointer, gint, GaimInputCondition);
-static unsigned char *roast_password(char *);
 static void accept_file_dialog(struct ft_request *);
 
 /* ok. this function used to take username/password, and return 0 on success.
@@ -139,6 +143,7 @@ static void toc_login(struct aim_user *user)
 
 	gc = new_gaim_conn(user);
 	gc->proto_data = tdt = g_new0(struct toc_data, 1);
+	gc->flags |= OPT_CONN_HTML;
 
 	g_snprintf(buf, sizeof buf, "Looking up %s",
 		   user->proto_opt[USEROPT_AUTH][0] ? user->proto_opt[USEROPT_AUTH] : TOC_HOST);
@@ -227,7 +232,6 @@ static int escape_message(char *msg)
 		case ']':
 		case '(':
 		case ')':
-		case '#':
 			msg[cnt++] = '\\';
 			/* Fall through */
 		default:
@@ -376,10 +380,10 @@ static void toc_got_info(gpointer data, char *url_text)
 	if (!url_text)
 		return;
 
-	g_show_info_text(url_text, NULL);
+	g_show_info_text(NULL, NULL, 2, url_text, NULL);
 }
 
-static char *show_error_message(char *d)
+static char *show_error_message()
 {
 	int no = atoi(strtok(NULL, ":"));
 	char *w = strtok(NULL, ":");
@@ -508,6 +512,9 @@ static void toc_callback(gpointer data, gint source, GaimInputCondition conditio
 		}
 
 		debug_printf("* Client sends TOC \"toc_signon\" message\n");
+		/* i hate icq. */
+		if (gc->username[0] >= '0' && gc->username[0] <= '9')
+			gc->password[9] = '\0';
 		g_snprintf(snd, sizeof snd, "toc_signon %s %d  %s %s %s \"%s\"",
 			   AUTH_HOST, AUTH_PORT, normalize(gc->username),
 			   roast_password(gc->password), LANGUAGE, REVISION);
@@ -528,8 +535,7 @@ static void toc_callback(gpointer data, gint source, GaimInputCondition conditio
 				     buf + sizeof(struct sflap_hdr));
 			if (!g_strncasecmp(buf + sizeof(struct sflap_hdr), "ERROR", 5)) {
 				strtok(buf + sizeof(struct sflap_hdr), ":");
-				hide_login_progress(gc, show_error_message(buf +
-							sizeof(struct sflap_hdr)));
+				hide_login_progress(gc, show_error_message());
 			} else
 				hide_login_progress(gc, _("Authentication Failed"));
 			signoff(gc);
@@ -547,7 +553,8 @@ static void toc_callback(gpointer data, gint source, GaimInputCondition conditio
 		account_online(gc);
 		serv_finish_login(gc);
 
-		do_import(gc, NULL);
+		if (bud_list_cache_exists(gc))
+			do_import(gc, NULL);
 
 		/* Client sends TOC toc_init_done message */
 		debug_printf("* Client sends TOC toc_init_done message\n");
@@ -582,7 +589,8 @@ static void toc_callback(gpointer data, gint source, GaimInputCondition conditio
 				signoff(gc);
 				return;
 			}
-			do_import(gc, NULL);
+			if (bud_list_cache_exists(gc))
+				do_import(gc, NULL);
 			g_snprintf(snd, sizeof snd, "toc_init_done");
 			sflap_send(gc, snd, -1, TYPE_DATA);
 			do_error_dialog(_("TOC has come back from its pause. You may now send"
@@ -590,7 +598,7 @@ static void toc_callback(gpointer data, gint source, GaimInputCondition conditio
 		}
 	} else if (!strcasecmp(c, "CONFIG")) {
 		c = strtok(NULL, ":");
-		parse_toc_buddy_list(gc, c, 0);
+		parse_toc_buddy_list(gc, c);
 	} else if (!strcasecmp(c, "NICK")) {
 		/* ignore NICK so that things get imported/exported properly
 		c = strtok(NULL, ":");
@@ -610,7 +618,7 @@ static void toc_callback(gpointer data, gint source, GaimInputCondition conditio
 
 		a = (away && (*away == 'T')) ? IM_FLAG_AWAY : 0;
 
-		serv_got_im(gc, c, message, a, time((time_t)NULL));
+		serv_got_im(gc, c, message, a, time(NULL), -1);
 	} else if (!strcasecmp(c, "UPDATE_BUDDY")) {
 		char *l, *uc, *tmp;
 		int logged, evil, idle, type = 0;
@@ -656,8 +664,7 @@ static void toc_callback(gpointer data, gint source, GaimInputCondition conditio
 
 		serv_got_update(gc, c, logged, evil, signon, time_idle, type, 0);
 	} else if (!strcasecmp(c, "ERROR")) {
-		c = strtok(NULL, ":");
-		show_error_message(c);
+		do_error_dialog(show_error_message(), "TOC Error");
 	} else if (!strcasecmp(c, "EVILED")) {
 		int lev;
 		char *name;
@@ -714,7 +721,7 @@ static void toc_callback(gpointer data, gint source, GaimInputCondition conditio
 				add_chat_buddy(b, buddy);
 		else
 			while ((buddy = strtok(NULL, ":")) != NULL)
-				remove_chat_buddy(b, buddy);
+				remove_chat_buddy(b, buddy, NULL);
 	} else if (!strcasecmp(c, "CHAT_INVITE")) {
 		char *name, *who, *message;
 		int *id = g_new0(int, 1);
@@ -763,7 +770,7 @@ static void toc_callback(gpointer data, gint source, GaimInputCondition conditio
 				gc->user->proto_opt[USEROPT_AUTHPORT][0] ?
 					atoi(gc->user->proto_opt[USEROPT_AUTHPORT]) : TOC_PORT,
 				url);
-		grab_url(tmp, toc_got_info, NULL);
+		grab_url(tmp, FALSE, toc_got_info, NULL);
 	} else if (!strcasecmp(c, "DIR_STATUS")) {
 	} else if (!strcasecmp(c, "ADMIN_NICK_STATUS")) {
 	} else if (!strcasecmp(c, "ADMIN_PASSWD_STATUS")) {
@@ -912,7 +919,7 @@ static char *toc_name()
 	return "TOC";
 }
 
-static int toc_send_im(struct gaim_connection *gc, char *name, char *message, int flags)
+static int toc_send_im(struct gaim_connection *gc, char *name, char *message, int len, int flags)
 {
 	char buf[BUF_LEN * 2];
 	char *tmp = g_malloc(strlen(message) * 4 + 1); /* 4 because \n gets replaced with <BR> */
@@ -1032,7 +1039,7 @@ static void toc_add_buddies(struct gaim_connection *g, GList *buddies)
 	sflap_send(g, buf, -1, TYPE_DATA);
 }
 
-static void toc_remove_buddy(struct gaim_connection *g, char *name)
+static void toc_remove_buddy(struct gaim_connection *g, char *name, char *group)
 {
 	char buf[BUF_LEN * 2];
 	g_snprintf(buf, sizeof(buf), "toc_remove_buddy %s", normalize(name));
@@ -1040,7 +1047,7 @@ static void toc_remove_buddy(struct gaim_connection *g, char *name)
 	toc_set_config(g);
 }
 
-static void toc_remove_buddies(struct gaim_connection *g, GList *buddies)
+static void toc_remove_buddies(struct gaim_connection *g, GList *buddies, char *group)
 {
 	char buf[BUF_LEN * 2];
 	int n;
@@ -1116,7 +1123,8 @@ static void toc_join_chat(struct gaim_connection *g, GList *data)
 static void toc_chat_invite(struct gaim_connection *g, int id, char *message, char *name)
 {
 	char buf[BUF_LONG];
-	g_snprintf(buf, sizeof(buf) / 2, "toc_chat_invite %d \"%s\" %s", id, message, normalize(name));
+	g_snprintf(buf, sizeof(buf) / 2, "toc_chat_invite %d \"%s\" %s", id,
+			message ? message : "", normalize(name));
 	sflap_send(g, buf, -1, TYPE_DATA);
 }
 
@@ -1232,6 +1240,7 @@ static void toc_add_permit(struct gaim_connection *gc, char *who)
 	g_snprintf(buf2, sizeof(buf2), "toc_add_permit %s", normalize(who));
 	sflap_send(gc, buf2, -1, TYPE_DATA);
 	toc_set_config(gc);
+	signoff_blocked(gc);
 }
 
 static void toc_add_deny(struct gaim_connection *gc, char *who)
@@ -1242,6 +1251,7 @@ static void toc_add_deny(struct gaim_connection *gc, char *who)
 	g_snprintf(buf2, sizeof(buf2), "toc_add_deny %s", normalize(who));
 	sflap_send(gc, buf2, -1, TYPE_DATA);
 	toc_set_config(gc);
+	signoff_blocked(gc);
 }
 
 static void toc_set_permit_deny(struct gaim_connection *gc)
@@ -1307,6 +1317,7 @@ static void toc_set_permit_deny(struct gaim_connection *gc)
 		break;
 	}
 	toc_set_config(gc);
+	signoff_blocked(gc);
 }
 
 static void toc_rem_permit(struct gaim_connection *gc, char *who)
@@ -1323,7 +1334,7 @@ static void toc_rem_deny(struct gaim_connection *gc, char *who)
 	toc_set_permit_deny(gc);
 }
 
-static GList *toc_away_states()
+static GList *toc_away_states(struct gaim_connection *gc)
 {
 	return g_list_append(NULL, GAIM_AWAY_CUSTOM);
 }
@@ -1355,7 +1366,7 @@ static struct prpl *my_protocol = NULL;
 void toc_init(struct prpl *ret)
 {
 	ret->protocol = PROTO_TOC;
-	ret->options = OPT_PROTO_HTML | OPT_PROTO_CORRECT_TIME;
+	ret->options = OPT_PROTO_CORRECT_TIME;
 	ret->name = toc_name;
 	ret->list_icon = toc_list_icon;
 	ret->away_states = toc_away_states;
@@ -1928,8 +1939,11 @@ static void accept_file_dialog(struct ft_request *ft) {
 			size /= 1024;
 			index++;
 		}
-	        g_snprintf(buf, sizeof(buf), _("%s requests %s to accept %d file%s: %s (%.2f %s)%s%s"),
-				ft->user, ft->gc->username, ft->files, (ft->files == 1) ? "" : "s",
+	        g_snprintf(buf, sizeof(buf), 
+				ft->files == 1 ? 
+				_("%s requests %s to accept %d file: %s (%.2f %s)%s%s") :
+				_("%s requests %s to accept %d files: %s (%.2f %s)%s%s"),
+				ft->user, ft->gc->username, ft->files, 
 				ft->filename, size, sizes[index], (ft->message) ? "\n" : "",
 				(ft->message) ? ft->message : "");
 	} else {
